@@ -20,7 +20,6 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <time.h>
-#include "vsys_def.h"
 
 int io_queue_run(io_context_t ctx)
 {
@@ -29,7 +28,7 @@ int io_queue_run(io_context_t ctx)
 	int ret;
 
 	/* FIXME: batch requests? */
-	while (1 == (ret = vsys_io_getevents(ctx, 1, &event, &timeout))) {
+	while (1 == (ret = io_getevents(ctx, 0, 1, &event, &timeout))) {
 		io_callback_t cb = (io_callback_t)event.data;
 		struct iocb *iocb = (struct iocb *)event.obj;
 
