@@ -21,11 +21,9 @@
 #include <libaio.h>
 #include <errno.h>
 
-#include "vsys_def.h"
-
 struct timespec;
 
 int io_queue_wait(io_context_t ctx, struct timespec *timeout)
 {
-	return vsys_io_getevents(ctx, 0, NULL, timeout);
+	return io_getevents(ctx, 0, 0, NULL, timeout);
 }
