@@ -20,7 +20,4 @@
 #include <libaio.h>
 #include "syscall.h"
 
-int io_submit(io_context_t ctx, long nr, struct iocb **iocbs)
-{
-	return syscall3(__NR_io_submit, ctx, nr, iocbs);
-}
+io_syscall3(int, io_submit, io_context_t, ctx, long, nr, struct iocb **, iocbs)
